@@ -500,6 +500,14 @@ contact_view_done_cb (MonorailContactChooser *chooser,
       GTK_WINDOW (data->contact_window), 0);
 }
 
+static void
+contact_view_working_cb (MonorailContactChooser *chooser,
+    MonorailData *data)
+{
+  hildon_gtk_window_set_progress_indicator (
+      GTK_WINDOW (data->contact_window), 1);
+}
+
 int
 main (int argc,
     char **argv)
@@ -546,8 +554,6 @@ main (int argc,
       create_menu (data));
   gtk_window_set_title (GTK_WINDOW (data->contact_window), "Select a contact");
   gtk_container_set_border_width (GTK_CONTAINER (data->contact_window), 5);
-  hildon_gtk_window_set_progress_indicator (
-      GTK_WINDOW (data->contact_window), 1);
 
   g_signal_connect (data->contact_window, "delete-event",
       G_CALLBACK (main_window_delete_event), data);
@@ -577,18 +583,19 @@ main (int argc,
 
   g_signal_connect (data->contact_view, "done",
       G_CALLBACK (contact_view_done_cb), data);
+  g_signal_connect (data->contact_view, "working",
+      G_CALLBACK (contact_view_working_cb), data);
   g_signal_connect (data->contact_view, "contact-activated",
       G_CALLBACK (contact_activated_cb), data);
 
   tree_view = osso_abook_tree_view_get_tree_view (
       OSSO_ABOOK_TREE_VIEW (data->contact_view));
 
-  data->live_search = osso_abook_live_search_new ();
-  osso_abook_live_search_set_filter (OSSO_ABOOK_LIVE_SEARCH (data->live_search),
+  data->live_search = osso_abook_live_search_new_with_filter (
       osso_abook_tree_view_get_filter_model (
           OSSO_ABOOK_TREE_VIEW (data->contact_view)));
-  osso_abook_live_search_widget_hook (OSSO_ABOOK_LIVE_SEARCH (data->live_search),
-      data->contact_window, tree_view);
+  hildon_live_search_widget_hook (HILDON_LIVE_SEARCH (data->live_search),
+      data->contact_window, GTK_WIDGET (tree_view));
   gtk_box_pack_start (GTK_BOX (vbox), data->live_search, FALSE, FALSE, 0);
   gtk_widget_hide (data->live_search);
 
@@ -602,7 +609,7 @@ main (int argc,
 
   gtk_main ();
 
-  if (data->no_ui)
+  if (!data->no_ui)
     gtk_widget_destroy (data->contact_window);
   g_object_unref (data->handler);
 
